==> axentix-2.0.0.tgz: package/README.md <==
<p align="center">
  <a href="https://useaxentix.com/">
    <img src="https://useaxentix.com/img/axentix.svg?" alt="Axentix Logo" width="120" height="120">
  </a>
</p>

<h3 align="center">Axentix - Front-end framework</h3>

<p align="center">
  <a href="https://useaxentix.com/?ref=github"><strong>Home</strong></a> |
  <a href="https://useaxentix.com/docs/?ref=github"><strong>Documentation</strong></a>
</p>

<br>

<p align="center">
  <a href="https://www.npmjs.com/package/axentix">
    <img alt="npm" src="https://img.shields.io/npm/v/axentix">
  </a>
  <a href="https://github.com/axentix/axentix/releases">
    <img alt="GitHub release (latest by date)" src="https://img.shields.io/github/v/release/axentix/axentix">
  </a>
  <a href="https://www.jsdelivr.com/package/npm/axentix">
    <img src="https://data.jsdelivr.com/v1/package/npm/axentix/badge?style=rounded" alt="jsDelivr Hits" />
  </a>
  <a href="https://sonarcloud.io/dashboard?id=axentix_axentix">
    <img src="https://sonarcloud.io/api/project_badges/measure?project=axentix_axentix&metric=alert_status">
  </a>
  <img alt="npm bundle size (version)" src="https://img.shields.io/bundlephobia/minzip/axentix/next">
  <a href="https://snyk.io/test/github/axentix/axentix?targetFile=package.json">
    <img src="https://snyk.io/test/github/axentix/axentix/badge.svg?targetFile=package.json" alt="Known Vulnerabilities" />
  </a>
  <img src="https://img.shields.io/github/license/axentix/axentix" alt="License" />
</p>

<p align="center">
  <a href="https://discord.gg/8tgRDED">
    <img src="https://img.shields.io/discord/727545620683816980" alt="Discord" />
  </a>
  <a href="https://openbase.io/js/axentix?utm_source=embedded&utm_medium=badge&utm_campaign=rate-badge">
    <img src="https://badges.openbase.io/js/rating/axentix.svg" alt="Rate on Openbase" />
  </a>
</p>

Axentix is a framework mixing fully customizable components & utility-first classes, leaving the design choice to the developer. 

![home gif](https://useaxentix.com/img/gif-home.gif?2)

## Quickstart

### NPM
```
npm install axentix
```

### Yarn
```
yarn add axentix
```

### CDN

Include the files with [jsDelivr](https://www.jsdelivr.com/package/npm/axentix).

### Github Release  
You can download the latest release from [Github](https://github.com/axentix/axentix/releases/latest).

### Clone the repo
```
git clone https://github.com/axentix/axentix.git
cd axentix
npm ci
```

After installation you have access to our source files.  
You can build project with `npm run build` or serve it with `npm run serve`.

## Documentation

Find the documentation at [https://useaxentix.com/docs/](https://useaxentix.com/docs/?ref=github).

## Changelog

Changelog is accessible in the [CHANGELOG.md](CHANGELOG.md) file or in [the release section](https://github.com/axentix/axentix/releases).

## Sponsors

Support this project on [BuyMeACoffee](https://www.buymeacoffee.com/axentix) to become a sponsor and get **your logo here and on the docs** with a link to your website.

<div align="center">
  <a href="https://www.buymeacoffee.com/axentix" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" alt="Become a sponsor" height="50" width="180"></a>
</div>

## Backers

Support this project on [BuyMeACoffee](https://www.buymeacoffee.com/axentix) to become a backer and get **your github profile here**.

[<img src="https://avatars.githubusercontent.com/u/32241342?v=4" width="40" style="border-radius:50%"/>](https://github.com/Xelzs)
[<img src="https://avatars.githubusercontent.com/u/49057921?v=4" width="40" style="border-radius:50%"/>](https://github.com/Stallos11)

## Creators

- Axel SIMONET - (Xelzs)  
  [Github](https://github.com/Xelzs)  
  [Linkedin](https://www.linkedin.com/in/axel-simonet/)  
  [Website](https://axelsimonet.fr/)
- Vincent LEVEQUE - (Stallos11)  
  [Github](https://github.com/Stallos11)  
  [Linkedin](https://www.linkedin.com/in/leveque-vincent/)

<br>

___

<p align="center">
Axentix Framework - Made with ❤️ by Axel SIMONET & Vincent LEVEQUE
</p>

==> axentix-2.1.0.tgz: package/README.md <==
<p align="center">
  <a href="https://useaxentix.com/">
    <img src="https://useaxentix.com/img/axentix.svg?" alt="Axentix Logo" width="120" height="120">
  </a>
</p>

<h3 align="center">Axentix - Front-end framework</h3>

<p align="center">
  <a href="https://useaxentix.com/?ref=github"><strong>Home</strong></a> |
  <a href="https://useaxentix.com/docs/?ref=github"><strong>Documentation</strong></a>
</p>

<br>

<p align="center">
  <a href="https://www.npmjs.com/package/axentix">
    <img alt="npm" src="https://img.shields.io/npm/v/axentix">
  </a>
  <a href="https://github.com/axentix/axentix/releases">
    <img alt="GitHub release (latest by date)" src="https://img.shields.io/github/v/release/axentix/axentix">
  </a>
  <a href="https://www.jsdelivr.com/package/npm/axentix">
    <img src="https://data.jsdelivr.com/v1/package/npm/axentix/badge?style=rounded" alt="jsDelivr Hits" />
  </a>
  <a href="https://sonarcloud.io/dashboard?id=axentix_axentix">
    <img src="https://sonarcloud.io/api/project_badges/measure?project=axentix_axentix&metric=alert_status">
  </a>
  <img alt="npm bundle size (version)" src="https://img.shields.io/bundlephobia/minzip/axentix/next">
  <a href="https://snyk.io/test/github/axentix/axentix?targetFile=package.json">
    <img src="https://snyk.io/test/github/axentix/axentix/badge.svg?targetFile=package.json" alt="Known Vulnerabilities" />
  </a>
  <img src="https://img.shields.io/github/license/axentix/axentix" alt="License" />
</p>

<p align="center">
  <a href="https://discord.gg/8tgRDED">
    <img src="https://img.shields.io/discord/727545620683816980" alt="Discord" />
  </a>
  <a href="https://openbase.com/js/axentix?utm_source=embedded&amp;utm_medium=badge&amp;utm_campaign=rate-badge">
    <img src="https://badges.openbase.com/js/rating/axentix.svg?token=xEWyuQ6VoC2qG3gEvoNm6V3hVAvXbAnGQXJTC9OkTrI=" alt="Rate this package" />
  </a>
</p>

Axentix is a framework mixing fully customizable components & utility-first classes, leaving the design choice to the developer. 

![top image](./top.png)

## Quickstart

### NPM
```
npm install axentix
```

### Yarn
```
yarn add axentix
```

### CDN

Include the files with [jsDelivr](https://www.jsdelivr.com/package/npm/axentix).

### Github Release  
You can download the latest release from [Github](https://github.com/axentix/axentix/releases/latest).

### Clone the repo
```
git clone https://github.com/axentix/axentix.git
cd axentix
npm ci
```

After installation you have access to our source files.  
You can build the project with `npm run build` or launch development server with `npm run dev`.

## Documentation

Find the documentation at [https://useaxentix.com/docs/](https://useaxentix.com/docs/?ref=github).

## Changelog

Changelog is accessible in the [CHANGELOG.md](CHANGELOG.md) file or in [the release section](https://github.com/axentix/axentix/releases).

## Sponsors

Support this project on [BuyMeACoffee](https://www.buymeacoffee.com/axentix) to become a sponsor and get **your logo on the docs** with a link to your website.

<div align="center">
  <a href="https://www.buymeacoffee.com/axentix" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" alt="Become a sponsor" height="50" width="180"></a>
</div>

## Backers

Support this project on [BuyMeACoffee](https://www.buymeacoffee.com/axentix) to become a backer and get **your github profile here**.

[<img src="https://avatars.githubusercontent.com/u/32241342?v=4" width="40" style="border-radius:50%"/>](https://github.com/Xelzs)
[<img src="https://avatars.githubusercontent.com/u/49057921?v=4" width="40" style="border-radius:50%"/>](https://github.com/Stallos11)

## Creators

- Axel SIMONET - (Xelzs)  
  [Github](https://github.com/Xelzs)  
  [Linkedin](https://www.linkedin.com/in/axel-simonet/)  
  [Website](https://axelsimonet.fr/)
- Vincent LEVEQUE - (Stallos11)  
  [Github](https://github.com/Stallos11)  
  [Linkedin](https://www.linkedin.com/in/leveque-vincent/)

<br>

___

<p align="center">
Axentix Framework - Made with ❤️ by Axel SIMONET & Vincent LEVEQUE
</p>
